# CDBUtils 1.0 Release Notes

CDBUtils 1.0 was released on 2020-02-29.

This is the first public release of CDBUtils.this is Database connections pool extension from DBUtils.

## Changes:

extension the DBUTils.PooledDB

- Added a `test_on_borrow` parameter for PooledDB： check availability of the connection fetched from the pool(True = check，False = default = never check).
- Added a `test_idle` parameter for PooledDB：Check connection availability on idle(是否检查空闲连接) (True = default = check，False = never check).
- Added a `validation_sql` parameter for PooledDB： the sql for validate the connection 测试连接的sql 。 (default is 'SELECT 1 FROM DUAL')
- Added a `idle_check_time` parameter for PooledDB： the seconds for Check and remove the idle connection interval,it will be start one Thread to check the idle connection in the pool, whenever 'idleCheckTime' greater than 0 and 'testIdle' is True,default is 60 seconds. (检查并移除连接池中空闲连接的时间间隔 小于等于0时不检查,默认60s)
- Added a `validate_timeout` parameter for PooledDB： the max seconds to execute the validation Sql,default is 1. if 'validateTimeOut' Less than 1, it will Wait until to return the result(执行校验sql语句的最大超时时间秒默认1s)
- Added a `max_wait_time` parameter for PooledDB：the max wait time for fetch one connection from the pool, if ‘maxWaitTime’ greater than 0 ,it will be start a lock for the function "connection " with in the time, and throw one exception when the timeout 在连接池中获取一个有效连接的最大超时时间 默认5s

## Bugfixes and Improvements: